Documentation Structure
Markdown sources
mdBook generates the documentation as a static Website from Markdown files.
The SparkleMuffin repository stores the documentation resources under the
docs/ directory:
docs/
├── book # Generated Website (not tracked in Git)
├── book.toml # mdBook configuration
└── src # Markdown source files
Sections and page categories
The documentation has two main sections:
- a User Guide that shows SparkleMuffin’s features and how to use them;
- a Developer Guide that explains how SparkleMuffin works, and how to contribute to the project.
The Diátaxis approach organizes pages into four categories:
- Tutorials: learning-oriented lessons that take you through a series of steps to use a feature;
- How-to Guides: practical step-by-step guides to help you achieve a specific goal;
- Reference Guides: details about how SparkleMuffin works;
- Concept Guides: thoughts and reflections about why things work the way they do.
Reference
- mdbook build command
- mdbook serve command
- SUMMARY.md
- mdBook Configuration
- Markdown